#  Created by tag_check.write_version
#  NEVER CHECK THIS version.py file INTO GIT.
#  It should be generated when the package is build for distribution.
__when__ = '15/04/2020 16:53:13'
__version__ = '0.16.7'
